# FlavorLineTool
a cli app for tracking cookies and interacting with flavortown

## features
- ability to check your stats (cookies and most used language)
- search for users (highly experimental for now due to api rules)
- check total time spent on your projects
- login with both flavortown and hackatime
- list all shop items and all users

## installation
soon you will be able to install flavorlinetool with pip!
